@@ -1,11 +1,11 @@
 '''
-This is the primary module for user-interaction with the `hmf` package.
+This is the primary module for user-interaction with the :mod:`hmf` package.
 
 The module contains a single class, `MassFunction`, which wraps almost all the
-functionality of `hmf` in an easy-to-use way.
+functionality of :mod:`hmf` in an easy-to-use way.
 '''
 
-version = '1.4.4'
+version = '1.4.5'
 
 ###############################################################################
 # Some Imports
@@ -179,6 +179,25 @@ class MassFunction(object):
         self.__M = 10 ** val
 
     @property
+    def delta_c(self):
+        return self.__delta_c
+
+    @delta_c.setter
+    def delta_c(self, val):
+        try:
+            val = float(val)
+        except ValueError:
+            raise ValueError("delta_c must be a number: ", val)
+
+        if val <= 0:
+            raise ValueError("delta_c must be > 0 (", val, ")")
+        if val > 10.0:
+            raise ValueError("delta_c must be < 10.0 (", val, ")")
+
+        self.__delta_c = val
+
+        del self.fsigma
+    @property
     def mf_fit(self):
         return self.__mf_fit
 
